@@ -38,6 +38,7 @@ class HerokuDeployer:
         self._configure_debug()
         self._configure_secret_key()
         self._conclude_automate_all()
+        self._summarize_deployment()
         self._show_success_message()
 
 
@@ -80,17 +81,25 @@ class HerokuDeployer:
         """Get info about the Heroku app we're pushing to."""
         # We assume the user has already run 'heroku create', or --automate-all
         #   has run it. If it hasn't been run, we'll quit and tell them to do so.
-        self.sd.write_output("  Inspecting Heroku app...")
-        cmd = 'heroku apps:info'
-        apps_info = self.sd.execute_subp_run(cmd)
-        self.sd.write_output(apps_info)
 
-        # Turn stdout info into a list of strings that we can then parse.
-        #   If no app exists, stdout is empty and the output went to stderr.
-        apps_info = apps_info.stdout.decode().split('\n')
-        # DEV: Use this code when we can require Python >=3.9.
-        # self.heroku_app_name = apps_info[0].removeprefix('=== ')
-        self.heroku_app_name = apps_info[0].replace('=== ', '')
+        # DEV: The testing approach here should be improved. We should be able
+        #   to easily test for a failed apps:info call. Also, probably want
+        #   to mock the output of apps:info rather than directly setting
+        #   heroku_app_name.
+        if self.sd.local_test:
+            self.heroku_app_name = 'sample-name-11894'
+        else:
+            self.sd.write_output("  Inspecting Heroku app...")
+            cmd = 'heroku apps:info'
+            apps_info = self.sd.execute_subp_run(cmd)
+            self.sd.write_output(apps_info)
+
+            # Turn stdout info into a list of strings that we can then parse.
+            #   If no app exists, stdout is empty and the output went to stderr.
+            apps_info = apps_info.stdout.decode().split('\n')
+            # DEV: Use this code when we can require Python >=3.9.
+            # self.heroku_app_name = apps_info[0].removeprefix('=== ')
+            self.heroku_app_name = apps_info[0].replace('=== ', '')
 
         if self.heroku_app_name:
             self.sd.write_output(f"    Found Heroku app: {self.heroku_app_name}")
@@ -105,6 +114,11 @@ class HerokuDeployer:
         """Set a config var to indicate when we're in the Heroku environment.
         This is mostly used to modify settings for the deployed project.
         """
+
+        # Skip this entirely when unit testing.
+        if self.sd.local_test:
+            return
+
         self.sd.write_output("  Setting Heroku environment variable...")
         cmd = 'heroku config:set ON_HEROKU=1'
         output = self.sd.execute_subp_run(cmd)
@@ -167,7 +181,7 @@ class HerokuDeployer:
 
     def _check_allowed_hosts(self):
         """Make sure project can be served from heroku."""
-        # This method is specific to Heroku, but the error message is not.
+        # This method is specific to Heroku.
 
         self.sd.write_output("\n  Making sure project can be served from Heroku...")
         heroku_host = f"{self.heroku_app_name}.herokuapp.com"
@@ -177,17 +191,11 @@ class HerokuDeployer:
         elif 'herokuapp.com' in settings.ALLOWED_HOSTS:
             # This is a generic entry that allows serving from any heroku URL.
             self.sd.write_output("    Found 'herokuapp.com' in ALLOWED_HOSTS.")
-        elif not settings.ALLOWED_HOSTS:
+        else:
             new_setting = f"ALLOWED_HOSTS.append('{heroku_host}')"
             msg_added = f"    Added {heroku_host} to ALLOWED_HOSTS for the deployed project."
             msg_already_set = f"    Found {heroku_host} in ALLOWED_HOSTS for the deployed project."
             self._add_heroku_setting(new_setting, msg_added, msg_already_set)
-        else:
-            # Let user know there's a nonempty ALLOWED_HOSTS, that doesn't 
-            #   contain the current Heroku URL.
-            msg = d_msgs.allowed_hosts_not_empty_msg(heroku_host)
-            self.write_output(msg, write_to_console=False)
-            raise CommandError(msg)
 
 
     def _configure_db(self):
@@ -300,11 +308,14 @@ class HerokuDeployer:
         # returns the bool value True for 'TRUE', and False for 'FALSE'.
         # Taken from: https://stackoverflow.com/a/56828137/748891
 
-        self.sd.write_output("  Setting DEBUG env var...")
-        cmd = 'heroku config:set DEBUG=FALSE'
-        output = self.sd.execute_subp_run(cmd)
-        self.sd.write_output(output)
-        self.sd.write_output("    Set DEBUG config variable to FALSE.")
+        # When unit testing, don't set the heroku config var, but do make
+        #   the change to settings.
+        if not self.sd.local_test:
+            self.sd.write_output("  Setting DEBUG env var...")
+            cmd = 'heroku config:set DEBUG=FALSE'
+            output = self.sd.execute_subp_run(cmd)
+            self.sd.write_output(output)
+            self.sd.write_output("    Set DEBUG config variable to FALSE.")
 
         # Modify settings to use the DEBUG config variable.
         new_setting = "DEBUG = os.getenv('DEBUG') == 'TRUE'"
@@ -324,11 +335,13 @@ class HerokuDeployer:
             new_secret_key = get_random_secret_key()
 
         # Set the new key as an env var on Heroku.
-        self.sd.write_output("  Setting new secret key for Heroku...")
-        cmd = f"heroku config:set SECRET_KEY={new_secret_key}"
-        output = self.sd.execute_subp_run(cmd)
-        self.sd.write_output(output)
-        self.sd.write_output("    Set SECRET_KEY config variable.")
+        #   Skip when unit testing.
+        if not self.sd.local_test:
+            self.sd.write_output("  Setting new secret key for Heroku...")
+            cmd = f"heroku config:set SECRET_KEY={new_secret_key}"
+            output = self.sd.execute_subp_run(cmd)
+            self.sd.write_output(output)
+            self.sd.write_output("    Set SECRET_KEY config variable.")
 
         # Modify settings to use the env var's value as the secret key.
         new_setting = "SECRET_KEY = os.getenv('SECRET_KEY')"
@@ -349,8 +362,6 @@ class HerokuDeployer:
         output = self.sd.execute_subp_run(cmd)
         self.sd.write_output(output)
         self.sd.write_output("  Committing changes...")
-        # output = subprocess.run(['git', 'commit', '-am', '"Configured project for deployment."'],
-        #         capture_output=True)
         # If we write this command as a string, the commit message will be split
         #   incorrectly.
         cmd_parts = ['git', 'commit', '-am', '"Configured project for deployment."']
@@ -396,6 +407,19 @@ class HerokuDeployer:
         self.sd.write_output(output)
 
 
+    def _summarize_deployment(self):
+        """Manage all tasks related to generating and showing the friendly
+        summary of the deployment.
+
+        This does not take the place of the platform's official documentation.
+          Instead, it gives the user a friendly entry into the platform's
+          official documentation. It also gives them a brief summary of some
+          followup steps they can take, for example making a second push, or
+          changing the URL of the deployed app.
+        """
+        self._generate_summary()
+
+
     def _show_success_message(self):
         """After a successful run, show a message about what to do next."""
 
@@ -453,4 +477,15 @@ class HerokuDeployer:
             f_settings.write("\nif 'ON_HEROKU' in os.environ:")
 
             # Won't need to add these lines anymore.
-            self.found_heroku_settings = True
\ No newline at end of file
+            self.found_heroku_settings = True
+
+    def _generate_summary(self):
+        """Generate the friendly summary, which is html for now."""
+        # Generate the summary file.
+        path = self.sd.log_dir_path / 'deployment_summary.html'
+
+        summary_str = "<h2>Understanding your deployment</h2>"
+        path.write_text(summary_str)
+
+        msg = f"\n  Generated friendly summary: {path}"
+        self.sd.write_output(msg)
